==> free-sa-1.2.1.tar.gz: free-sa-1.2.1/src/reports/r_typical.c <==
#include "global.h"


struct reportTT TT[TTNUMBER];


void ReportTypical(void) {
    FILE *TTR;
    short int i, tIndic;
    time_t tTime;
    char turl[MAXLEN], tname[MAXUSERNAME], otname[MAXUSERNAME], tfname[MAXFILENAME];
    struct SAentry *res = NULL;


    for (i = 0; i < TTNUMBER; i++) {
	if (cfg.TTR[i]) {
	    /* TT_UNS: close */
	    SAfclose(TT[i].file, TT[i].fname);

	    /* TT: sort and generate report only if there is records */
	    if (TT[i].count) {
		strcpy(tfname, TT[i].fname);
		tfname[strlen(tfname) - 4L] = '\0';
		
		/* TT_UNS: sort by name(reverse) and datetime(normal,numeric) */
		SAsystem(CMDSORT, CMDSORT, "-k", "1,1r", "-k", "2,2n", "-o", tfname, TT[i].fname, NULL);
		/* TT_UNS: delete */
		SAunlink(TT[i].fname);
		
		/* TT_SRT: open */
		TT[i].file = SAfopenI("r", tfname);
		/* TTR: open */
		sprintf(turl, "%s, %s (%s, %s)", loc->User, loc->DnT, loc->Desc, loc->Asc); 
		TTR = SAfopenH("../", 'l', loc->TT[i], turl, 1, "w", "%s/%s.html", icfg.ReportDir, icfg.TTRname[i]);
		
		/* TTR: write main table header */
		fprintf(TTR, "\t<tr><th>%s<th>%s<th>%s\n", loc->User, loc->DnT, loc->URL);
		
		/* TTR: write user stats */
		otname[0] = '\0';
		while(fscanf(TT[i].file, "%s %ld %s %hd\n", tname, &tTime, turl, &tIndic) == 4) {
		    if (strcmp(otname, tname)) {
			strcpy(otname, tname);
    			res = SAentryByName(tname);
		    }
		    else tname[0] = '\0';
		
		    fprintf(TTR, "<tr><td>%s<td>%s<td><a href=\"%s\">%s</a>", (tname[0] == '\0') ? "" : res->vname, GetDT(tTime, "%x&nbsp;%X"), turl, LimitedURL(turl));
		    Indics(TTR, tIndic);
		}
		
		/* TTR: close */
    		SAfcloseH(TTR, icfg.TTRname[i]);
		
		/* TT_SRT: close and delete */
		SAfcloseU(TT[i].file, tfname);
	    } else SAunlink(TT[i].fname); /* TT_UNS: delete */
	} 
    }
}

==> free-sa-1.2.4.tar.gz: free-sa-1.2.4/src/reports/r_typical.c <==
#include "global.h"


struct reportTT TT[TTNUMBER];


void ReportTypical(void) {
    FILE *TTR;
    short int i, tIndic;
    time_t tTime;
    char turl[MAXLEN], tname[MAXUSERNAME], otname[MAXUSERNAME], tfname[MAXFILENAME];
    struct SAentry *res = NULL;


    for (i = 0; i < TTNUMBER; i++) {
	if (cfg.TTR[i]) {
	    /* TT_UNS: close */
	    SAfclose(TT[i].file, TT[i].fname);

	    /* TT: sort and generate report only if there is records */
	    if (TT[i].count) {
		strcpy(tfname, TT[i].fname);
		tfname[strlen(tfname) - 4L] = '\0';
		
		/* TT_UNS: sort by name(reverse) and datetime(normal,numeric) */
		SAsystem(CMDSORT, CMDSORT, "-k", "1,1r", "-k", "2,2n", "-o", tfname, TT[i].fname, NULL);
		/* TT_UNS: delete */
		SAunlink(TT[i].fname);
		
		/* TT_SRT: open */
		TT[i].file = SAfopenI("r", tfname);
		/* TTR: open */
		snprintf(turl, sizeof(turl), "%s, %s (%s, %s)", loc->User, loc->DnT, loc->Desc, loc->Asc); 
		TTR = SAfopenH("../", 'l', loc->TT[i], turl, 1, "w", "%s/%s.html", icfg.ReportDir, icfg.TTRname[i]);
		
		/* TTR: write main table header */
		fprintf(TTR, "\t<tr><th>%s<th>%s<th>%s\n", loc->User, loc->DnT, loc->URL);
		
		/* TTR: write user stats */
		otname[0] = '\0';
		while(fscanf(TT[i].file, "%s %ld %s %hd\n", tname, &tTime, turl, &tIndic) == 4) {
		    if (strcmp(otname, tname)) {
			strcpy(otname, tname);
    			res = SAentryByName(tname);
		    }
		    else tname[0] = '\0';
		
		    fprintf(TTR, "<tr><td>%s<td>%s<td><a href=\"%s\">%s</a>", (tname[0] == '\0') ? "" : res->vname, GetDT(tTime, "%x&nbsp;%X"), turl, LimitedURL(turl));
		    Indics(TTR, tIndic);
		}
		
		/* TTR: close */
    		SAfcloseH(TTR, icfg.TTRname[i]);
		
		/* TT_SRT: close and delete */
		SAfcloseU(TT[i].file, tfname);
	    } else SAunlink(TT[i].fname); /* TT_UNS: delete */
	} 
    }
}
